==> dialserver-0.3.3.tar.gz: dialserver-0.3.3/conf.h <==
// conf.h
//
// Configuration file acquisition
//
// Copyright (c) 2001,2002 Andrew McGill and Leading Edge Business Solutions
//
// This file is part of dialserver.
//
// dialserver is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// dialserver is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// dialserver; if not, write to the Free Software Foundation, Inc., 59 Temple
// Place, Suite 330, Boston, MA  02111-1307  USA

#define MAX_CLIENTBUFFER 20	// Hey! That's quite a lot!
#define CONFIGFILE "/etc/dialserver.conf"
				// Notice the complete absence of a path :(
// Configuration information
typedef struct CONFSTRUCT_ {
	char *cmdcheck;		// Command to check if the link is up
	char *reg_up;		// Matches output of cmdcheck when link is up
	char *reg_notup;	// Matches output of cmdcheck when link is down
	char *cmdpackets;	// Command to count packets (ifconfig)
	char *reg_rx;		// Packets received regex
	char *reg_tx;		// Packets transmitted regex
	char *cmddiagnose;	// Command to diagnose the link
	char *reg_islocal;	// Regular expression match for local URL'e
	char *reg_simplifyurl;	// Extract host part from url
	char *reg_linkisvalid;	// Matches valid link specifiers
	int timeoutdial;	// Time to wait before declaring a dial dead
	int timeouthangup;	// Time to wait before assuming a hangup successful [BOGUS]
	int timepacketcheck;	// Time over which to measure the packets on the link
	int timepoll;		// How often do we check whether we're dialled in
	int minimumpackets;	// The minumum number of packets which must pass over the link in that time
	int minimumpacketspermin;// The minumum number of packets which must pass over the link per minute
	char *unixsocket;	// AF_UNIX control socket path to listen on 
	char *pidfile;		// Path to file containing PID of running dialserver
	int tcpport;		// TCP port to listen on 
	char *passwdfile;	// Name of dialserver password file (htpasswd format)
	char *cmdcheckpasswd;	// Squid authentication program
	// Dialling
	char *cmdbeforedial;	// Script executed before we dial
	char *cmddial;		// Command to initiate dialling
	char *cmdafterdial;	// Script executed when we have connected
	char *cmddialtimeout;	// Script executed if a connection cannot be established
	int timeminimumcall;	// How many seconds from new call to contemplating hangup 
	// Link stuff
	char *reg_linkrx;	// Link Packets received regex
	char *reg_linktx;	// Link Packets transmitted regex
	char *cmdlinkrx;	// Link Packets received command
	char *cmdlinktx;	// Link Packets transmitted command
	// Wake up while on line
	int timerefresh;	// How often do we wake up
	char *cmdrefresh;	// A command to do when we wake up
	char *cmdduring;	// This is started when the line comes up, and killed when the line drops
	char *cmdlistidle;	// List idle connections
	int timelinkidle;	// If an individual connection is idle for this many seconds, it is killed - default is timepacketcheck*1.5
	int timeidlecheck;	// How often do we check for an idle link (seconds)
	// Wake up while off line
	int timewakeoff;	// How often do we wake up
	char *cmdwakeoff;	// What do we do each time we wake up
	// Hanging up
	char *cmdbeforehangup;	// Script to run before we hang up the connection
	char *cmdhangup;	// Command to hang up the link
	char *cmdafterhangup;	// Script to run when the hangup is successful, or when the line is dropped
	char *cmdhanguptimeout;	// Script to run if the hangup does not succeed
	// Log out
	char *cmdlogin;		// Script after a user logs in
	char *cmdiptoname;	// Script to translate ip to name
	char *cmdlogout;	// Script after a user logs out
	// Logging
	char *logfile;		// Where do we log to (besides to stdout and errs to stderr)
	// Authentication (automatic)
	int autoauth;		// Do we use $HOME/.dialserver-auth?
} CONFSTRUCT;

CONFSTRUCT conf;

int dlr_loadconfig(char *afilename, char *anargv0);
int dlr_reloadconfig(void);

==> dialserver-0.3.8.tar.gz: dialserver-0.3.8/conf.h <==
// conf.h
//
// Configuration file acquisition
//
// Copyright (c) 2001,2002 Andrew McGill and Leading Edge Business Solutions
//
// This file is part of dialserver.
//
// dialserver is free software; you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// dialserver is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along with
// dialserver; if not, write to the Free Software Foundation, Inc., 59 Temple
// Place, Suite 330, Boston, MA  02111-1307  USA

#define MAX_CLIENTBUFFER 20	// Hey! That's quite a lot!
#define CONFIGFILE "/etc/dialserver.conf"
				// Notice the complete absence of a path :(
// Configuration information
typedef struct CONFSTRUCT_ {
	char *cmdcheck;		// Command to check if the link is up
	char *reg_up;		// Matches output of cmdcheck when link is up
	char *reg_notup;	// Matches output of cmdcheck when link is down
	char *cmdpackets;	// Command to count packets (ifconfig)
	char *reg_rx;		// Packets received regex
	char *reg_tx;		// Packets transmitted regex
	char *cmddiagnose;	// Command to diagnose the link
	//char *reg_islocal;	// Regular expression match for local URL'e
	//char *reg_simplifyurl;	// Extract host part from url
	char *reg_linkisvalid;	// Matches valid link specifiers
	int timeoutdial;	// Time to wait before declaring a dial dead
	int timeouthangup;	// Time to wait before assuming a hangup successful [BOGUS]
	int timepacketcheck;	// Time over which to measure the packets on the link
	int timepoll;		// How often do we check whether we're dialled in
	int minimumpackets;	// The minumum number of packets which must pass over the link in that time
	int minimumpacketspermin;// The minumum number of packets which must pass over the link per minute
	char *unixsocket;	// AF_UNIX control socket path to listen on 
	char *pidfile;		// Path to file containing PID of running dialserver
	int tcpport;		// TCP port to listen on 
	char *passwdfile;	// Name of dialserver password file (htpasswd format)
	char *cmdcheckpasswd;	// Squid authentication program
	// Dialling
	char *cmddial;		// Command to initiate dialling
	char *cmdafterdial;	// Script executed when we have connected
	char *cmddialtimeout;	// Script executed if a connection cannot be established
	int timeminimumcall;	// How many seconds from new call to contemplating hangup 
	// Link stuff
	char *reg_linkrx;	// Link Packets received regex
	char *reg_linktx;	// Link Packets transmitted regex
	char *cmdlinkrx;	// Link Packets received command
	char *cmdlinktx;	// Link Packets transmitted command
	// Wake up while on line
	int timerefresh;	// How often do we wake up
	char *cmdrefresh;	// A command to do when we wake up
	char *cmdduring;	// This is started when the line comes up, and killed when the line drops
	char *cmdlistidle;	// List idle connections
	int timelinkidle;	// If an individual connection is idle for this many seconds, it is killed - default is timepacketcheck*1.5
	int timeidlecheck;	// How often do we check for an idle link (seconds)
	// Wake up while off line
	int timewakeoff;	// How often do we wake up
	char *cmdwakeoff;	// What do we do each time we wake up
	// Hanging up
	char *cmdhangup;	// Command to hang up the link
	char *cmdafterhangup;	// Script to run when the hangup is successful, or when the line is dropped
	char *cmdhanguptimeout;	// Script to run if the hangup does not succeed
	// Log out
	char *cmdlogin;		// Script after a user logs in
	char *cmdiptoname;	// Script to translate ip to name
	char *cmdlogout;	// Script after a user logs out
	// Logging
	char *logfile;		// Where do we log to (besides to stdout and errs to stderr)
	// Authentication (automatic)
	int autoauth;		// Do we use $HOME/.dialserver-auth?
} CONFSTRUCT;

CONFSTRUCT conf;

int dlr_loadconfig(char *afilename, char *anargv0);
int dlr_reloadconfig(void);
